==> idris-1.3.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.3.1
id: idris-1.3.1-13joYp8ogcwCiYuCpjmpU4
key: idris-1.3.1-13joYp8ogcwCiYuCpjmpU4
license: BSD-3-Clause
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
author: Edwin Brady
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
abi: 8e6e5abf9dda4e009ca0c0c4b5ac0947
exposed: True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Paths_idris Version_idris
                Tools_idris BuildFlags_idris
import-dirs: /usr/lib/ghc-8.6.3/site-local/idris-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/idris-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.3.1-13joYp8ogcwCiYuCpjmpU4
extra-libraries:
    gmp
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ array-0.5.3.0
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    base64-bytestring-1.0.0.2-EczxCDNMKyZ4D2mi23kJIl binary-0.8.6.0
    blaze-html-0.9.1.1-BgfYHwfc8MB4VF6u8ZvMhm
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    cheapskate-0.1.1.1-5vCVH2eWAmm63ZFc6K49aN
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    fingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
    fsnotify-0.3.0.1-2o4yGtrkfLY7EodEPAolJk haskeline-0.7.4.3
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    libffi-0.1-B7BBBCt8Sd58IwpXe6mL8r
    megaparsec-6.5.0-H5MWefGxGiGFtwgr5wTmKz mtl-2.2.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U pretty-1.1.3.6
    process-1.6.3.0 regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
    terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY text-1.2.3.1
    time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-5WXfN73XYIM6b4jVpCgYtD unix-2.7.2.2
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-binary-instances-0.2.5.1-9v2Hs4Y2fvx4gqXXobe9KA
    zip-archive-0.3.3-FtEZ8cVpsWW1rhccfBNhic
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> idris-1.3.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.3.1
id: idris-1.3.1-3wxiip2eMWQHCg1Shql1pD
key: idris-1.3.1-3wxiip2eMWQHCg1Shql1pD
license: BSD-3-Clause
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
author: Edwin Brady
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
abi: 2909d9308a09878e03228cfb0f7b48ce
exposed: True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Paths_idris Version_idris
                Tools_idris BuildFlags_idris
import-dirs: /usr/lib/ghc-8.6.3/site-local/idris-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/idris-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.3.1-3wxiip2eMWQHCg1Shql1pD
extra-libraries:
    gmp
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ array-0.5.3.0
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    base64-bytestring-1.0.0.2-EczxCDNMKyZ4D2mi23kJIl binary-0.8.6.0
    blaze-html-0.9.1.1-BgfYHwfc8MB4VF6u8ZvMhm
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    cheapskate-0.1.1.1-CrdOvcPgJevIyS0Mz5kZbd
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs containers-0.6.0.1
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    fingertree-0.1.4.2-9GfNn90LrWwLpCJ2A4ySYJ
    fsnotify-0.3.0.1-2o4yGtrkfLY7EodEPAolJk haskeline-0.7.4.3
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    libffi-0.1-B7BBBCt8Sd58IwpXe6mL8r
    megaparsec-6.5.0-H5MWefGxGiGFtwgr5wTmKz mtl-2.2.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U pretty-1.1.3.6
    process-1.6.3.0 regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
    terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY text-1.2.3.1
    time-1.8.0.2 transformers-0.5.5.0
    uniplate-1.6.12-5WXfN73XYIM6b4jVpCgYtD unix-2.7.2.2
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-binary-instances-0.2.5.1-9v2Hs4Y2fvx4gqXXobe9KA
    zip-archive-0.3.3-FtEZ8cVpsWW1rhccfBNhic
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
